--
-- SampleModMap
--
-- @author  Stefan Geiger
-- @date  12/07/10
--
-- Copyright (C) GIANTS Software GmbH, Confidential, All Rights Reserved.

SampleModMap = {}

local SampleModMap_mt = Class(SampleModMap, Mission00);


function SampleModMap:new(baseDirectory, customMt)
    local mt = customMt;
	if mt == nil then
        mt = SampleModMap_mt;
    end;
	
	local additionalFruitTypesPath = Utils.getFilename('additionalFruitTypes.lua', baseDirectory);
	print("loading AdditionalFruitTypes")
	if fileExists(additionalFruitTypesPath) then
	source(additionalFruitTypesPath);
	AdditionalFruitTypes:run(baseDirectory);
	else
	print("AdditionalFruitTypes.lua not found!")
	end;
	
    local self = SampleModMap:superClass():new(baseDirectory, mt);

    return self;
end;

function SampleModMap:delete()
    SampleModMap:superClass().delete(self);
end;

function SampleModMap:load()
    self:startLoadingTask();

    self.environment = Environment:new(Utils.getFilename("$data/sky/sky_day_night.i3d", self.baseDirectory), true, 8, true, true);

    self.helpIconsBase = nil;
    self.collectableGoldCoinsObject = nil;
    self.fieldDefinitionBase = nil;
    self.vehicleShopBase = nil;
	self.AnimationMapConfig = {"map/scripts/AnimationMap.xml", self.baseDirectory};

    self:loadMap(Utils.getFilename("map/map01.i3d", self.baseDirectory), true, self.loadCareerMap01Finished, self);
end;

function SampleModMap:loadCareerMap01Finished(node, arguments)
    if self.cancelLoading then
        return;
    end
    local startedRepeat = startFrameRepeatMode();
    trcScreenFlip();
		self:loadMapXMLFile(Utils.getFilename("SampleModMap.xml", self.baseDirectory));
    trcScreenFlip();
		self:loadTyreTrackSystem(Utils.getFilename("$data/vehicles/shared/tyreTrackMaterialHolder.i3d", self.baseDirectory));
    trcScreenFlip();
		self:loadI3D("$data/vehicles/particleAnimations/particle_materialHolder.i3d"); -- particle der standard Früchte
    trcScreenFlip();
		self:loadI3D("map/vehicles/particleAnimations/fertilizer_particleAnimations.i3d"); -- Dünger
    trcScreenFlip();
		self:loadI3D("map/vehicles/particleAnimations/kalk_particleAnimations.i3d"); -- Kalk
    trcScreenFlip();
	    self:loadI3D("map/vehicles/particleAnimations/compost_soil_particleAnimations.i3d"); -- Compost Erde
    trcScreenFlip();
	    self:loadI3D("map/vehicles/particleAnimations/seeds_particleAnimations.i3d"); -- seeds
    trcScreenFlip();
	    self:loadI3D("map/vehicles/particleAnimations/seeds2_particleAnimations.i3d"); -- seeds2 (SeedMaster2K15)
    trcScreenFlip();
		self:loadI3D("$data/vehicles/fillPlanes/fillPlane_materialHolder.i3d");
	trcScreenFlip();
		self:loadI3D("map/vehicles/fillPlanes/fertilizer.i3d"); -- Düngerplane
	trcScreenFlip();
	    self:loadI3D("map/vehicles/fillPlanes/kalk.i3d"); -- Kalkplane
	trcScreenFlip();
	    self:loadI3D("map/vehicles/fillPlanes/compost_soil.i3d"); -- compost_soil Plane
	trcScreenFlip();
	    self:loadI3D("map/vehicles/fillPlanes/seeds.i3d"); -- seedsPlane
	trcScreenFlip();
	    self:loadI3D("map/vehicles/fillPlanes/seeds2.i3d"); -- seeds2Plane (SeedMaster2K15)
	trcScreenFlip();
    self.ingameMap:loadMap(Utils.getFilename("pda_map.png", self.baseDirectory), 2048, 2048);

	trcScreenFlip();
    g_statisticView:setMapViewsMap(Utils.getFilename("pda_map.png", self.baseDirectory), 2048, 2048);

	trcScreenFlip();
	-- shops
    self.ingameMap:createMapHotspot("Shop", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_shop.png", self.baseDirectory), 82.601, -92.986, nil, nil, false, false, false, 0, true);
    local gardenCenterHotspot = self.ingameMap:createMapHotspot("Shop", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_shop.png", self.baseDirectory), 153.953, 7.138, nil, nil, false, false, true, 0, true);
    gardenCenterHotspot.fullViewName = g_i18n:getText("gardenCenter");

    -- egg sellpoints
    self.ingameMap:createMapHotspot("Eggs", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_eggs.png", self.baseDirectory), 2.166, 8.572, nil, nil, false, false, false, 0, true);
    
    -- farm silos
    self.ingameMap:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_tipPlace.png", self.baseDirectory), 485.502, 161, nil, nil, false, false, false, 0, true);
    
    -- bga
    self.ingameMap:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_tipPlace.png", self.baseDirectory), 10, 730, nil, nil, false, false, false, 0, true);
    
    -- grass heaps
    self.ingameMap:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_tipPlaceGreen.png", self.baseDirectory), 150.681, 30.7, nil, nil, false, false, false, 0, true);

    -- livestock
    self.ingameMap:createMapHotspot("Cows", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_cows.png", self.baseDirectory), 408.571, 236.595, nil, nil, false, false, false, 0, true);
    self.ingameMap:createMapHotspot("Sheep", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_sheep.png", self.baseDirectory), 79.669, 312.298, nil, nil, false, false, false, 0, true);
    self.ingameMap:createMapHotspot("Chickens", Utils.getFilename("$dataS2/menu/hud/hud_pda_spot_chickens.png", self.baseDirectory), 373.265, 150.569, nil, nil, false, false, false, 0, true);
    
	trcScreenFlip();
    SampleModMap:superClass().load(self);

	trcScreenFlip();

    if startedRepeat then
        endFrameRepeatMode();
    end
    self:finishLoadingTask();
end;

function SampleModMap:onStartMission()
    SampleModMap:superClass().onStartMission(self);
end;

function SampleModMap:mouseEvent(posX, posY, isDown, isUp, button)
    SampleModMap:superClass().mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function SampleModMap:keyEvent(unicode, sym, modifier, isDown)
    SampleModMap:superClass().keyEvent(self, unicode, sym, modifier, isDown);
end;

function SampleModMap:update(dt)
    SampleModMap:superClass().update(self, dt);
end;

function SampleModMap:draw()
    SampleModMap:superClass().draw(self);
end;
